@@ -2,6 +2,9 @@ from janis_core import File
 
 
 class ZipFile(File):
+    def __init__(self, optional=False, extension=".zip"):
+        super().__init__(optional, extension=extension)
+
     @staticmethod
     def name():
         return "Zip"
